/*
 * Copyright (C) 2004 Tilman Sauerbeck (tilman at code-monkey de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <ruby.h>

#include <Evas.h>

#include "rb_evas_main.h"
#include "rb_evas.h"
#include "rb_evas_object.h"

static VALUE c_init (VALUE self, VALUE evas)
{
	CHECK_CLASS (evas, cEvas);
	GET_OBJ (evas, RbEvas, e);
	GET_OBJ (self, RbEvasObject, line);

	line->real = evas_object_line_add (e->real);

	rb_call_super (1, &evas);

	return self;
}

static VALUE c_get_xy (VALUE self)
{
	int coord[4] = {0, 0, 0, 0};

	GET_OBJ (self, RbEvasObject, e);

	evas_object_line_xy_get (e->real, &coord[0], &coord[1],
	                         &coord[2], &coord[3]);

	return rb_ary_new3 (4, INT2FIX (coord[0]), INT2FIX (coord[1]),
	                    INT2FIX (coord[2]), INT2FIX (coord[3]));
}

static VALUE c_set_xy (VALUE self, VALUE x1, VALUE y1,
                       VALUE x2, VALUE y2)
{
	GET_OBJ (self, RbEvasObject, e);

	Check_Type (x1, T_FIXNUM);
	Check_Type (y1, T_FIXNUM);
	Check_Type (x2, T_FIXNUM);
	Check_Type (y2, T_FIXNUM);

	evas_object_line_xy_set (e->real, FIX2INT (x1), FIX2INT (y1),
	                         FIX2INT (x2), FIX2INT (y2));

	return Qnil;
}

void Init_Line (void)
{
	VALUE c = rb_define_class_under (mEvas, "Line", cEvasObject);

	rb_define_method (c, "initialize", c_init, 1);
	rb_define_method (c, "get_xy", c_get_xy, 0);
	rb_define_method (c, "set_xy", c_set_xy, 4);
}
