/*
 * Copyright (C) 2004 Tilman Sauerbeck (tilman at code-monkey de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <ruby.h>

#include <Evas.h>

#include "rb_evas_main.h"
#include "rb_evas.h"
#include "rb_evas_object.h"

/*
 * call-seq:
 *  Evas::Polygon.new(evas) => polygon
 *
 * Creates an new Evas::Polygon object.
 */
static VALUE c_init (VALUE self, VALUE evas)
{
	CHECK_CLASS (evas, cEvas);
	GET_OBJ (evas, RbEvas, e);
	GET_OBJ (self, RbEvasObject, poly);

	poly->real = evas_object_polygon_add (e->real);

	rb_call_super (1, &evas);

	return self;
}

/*
 * call-seq:
 *  polygon.add_point(x, y) => nil
 *
 * Adds a point to <i>polygon</i>.
 */
static VALUE c_add_point (VALUE self, VALUE x, VALUE y)
{
	GET_OBJ (self, RbEvasObject, e);

	Check_Type (x, T_FIXNUM);
	Check_Type (y, T_FIXNUM);

	evas_object_polygon_point_add (e->real, FIX2INT (x), FIX2INT (y));

	return Qnil;
}

/*
 * call-seq:
 *  polygon.clear_points => nil
 *
 * Clears the points of <i>polygon</i>.
 */
static VALUE c_clear_points (VALUE self)
{
	GET_OBJ (self, RbEvasObject, e);

	evas_object_polygon_points_clear (e->real);

	return Qnil;
}

void Init_Polygon (void)
{
	VALUE c = rb_define_class_under (mEvas, "Polygon", cEvasObject);

	rb_define_method (c, "initialize", c_init, 1);
	rb_define_method (c, "add_point", c_add_point, 2);
	rb_define_method (c, "clear_points", c_clear_points, 0);
}
